ElixirDatasets.Utils.Saver (ElixirDatasets v0.1.0)
View SourceUtility functions for saving datasets to various file formats.
Supports saving to CSV, Parquet, and JSONL files.
Summary
Functions
Saves the given dataframe to a file specified in the options. Options can include
Functions
@spec save_dataset_to_file( Explorer.DataFrame.t(), keyword() ) :: Path.t() | {:error, String.t()}
Saves the given dataframe to a file specified in the options. Options can include:
- :filepath - the path to save the file
- :file_extension - the file extension/type (csv, parquet, jsonl)